| Title: | Automated Gene Identification for Post-GWAS and QTL Analysis |
|---|---|
| Description: | Facilitates the post-Genome Wide Association Studies (GWAS) and Quantitative Trait Loci (QTL) analysis of identifying candidate genes within user-defined search window, based on the identified Single Nucleotide Polymorphisms (SNPs) as given by Mazumder AK (2024) <doi:10.1038/s41598-024-66903-3>. It supports candidate gene analysis for wheat and rice. Just import your GWAS result as explained in the sample_data file and the function does all the manual search and retrieve candidate genes for you, while exporting the results into ready-to-use output. |
| Authors: | Rajamani Nirmalaruban [aut, cre, cph], R. Suvitha [aut], Rajbir Yadav [aut], Meda Alekya [aut], Amit Kumar Mazumder [aut], Subramani Sugumar [aut], Prashanth babu [aut], Manjeet Kumar [aut], Kiran B Gaikwad [aut], Naresh Kumar Bainsla [aut], S. Bhaskar Reddy [aut] |
| Maintainer: | Rajamani Nirmalaruban <[email protected]> |
| License: | CC BY 4.0 |
| Version: | 2.0.1 |
| Built: | 2026-06-01 10:50:41 UTC |
| Source: | https://github.com/cran/geneNR |
Identifies Candidate Genes based on identified Quantitative Trati Loci (QTL) analysis
geneQTL(data_file, crop = "wheat")geneQTL(data_file, crop = "wheat")
data_file |
The input data in .csv format. (sample_data_wheat_qtl or sample_data_rice_qtl for demo purpose) |
crop |
Either "wheat" or "rice". (by default it will be wheat) |
A data frame containing traits, QTL, gene_id, gene_size, and gene_type.
load(system.file("extdata", "precomputed_sample_results_qtl.rda", package = "geneNR")) message(sample_results) result <- geneQTL("sample_data_wheat_qtl", crop="wheat") result <- geneQTL("sample_data_rice_qtl", crop="rice") #result <- geneQTL("your_results.csv", crop="wheat")load(system.file("extdata", "precomputed_sample_results_qtl.rda", package = "geneNR")) message(sample_results) result <- geneQTL("sample_data_wheat_qtl", crop="wheat") result <- geneQTL("sample_data_rice_qtl", crop="rice") #result <- geneQTL("your_results.csv", crop="wheat")
Identifies Candidate Genes based on identified Single Nucleotide Ploymorphisms (SNPs) from Genome Wide Association Stuides (GWAS) Analysis
geneSNP(data_file, upstream = 1e+06, downstream = 1e+06, crop = "wheat")geneSNP(data_file, upstream = 1e+06, downstream = 1e+06, crop = "wheat")
data_file |
The input data in .csv format. (sample_data_wheat or sample_data_rice for demo purpose) |
upstream |
The search window upstream of the current position of the SNP. (default: 1000000) |
downstream |
The search window downstream of the current position of the SNP. (default: 1000000) |
crop |
Either "wheat" or "rice". (default: wheat) |
A data frame containing traits, SNP, gene_id, gene_size, and gene_type.
load(system.file("extdata", "precomputed_sample_results.rda", package = "geneNR")) message(sample_results) result <- geneSNP("sample_data_wheat", 10000, 10000, crop = "wheat") result <- geneSNP("sample_data_rice", 10000, 10000, crop = "rice")load(system.file("extdata", "precomputed_sample_results.rda", package = "geneNR")) message(sample_results) result <- geneSNP("sample_data_wheat", 10000, 10000, crop = "wheat") result <- geneSNP("sample_data_rice", 10000, 10000, crop = "rice")
Identifies Candidate Genes based on identified Single Nucleotide Ploymorphisms (SNPs) from Genome Wide Association Stuides (GWAS) Analysis
geneSNPcustom(data_file, crop = "wheat")geneSNPcustom(data_file, crop = "wheat")
data_file |
The input data in .csv format. (sample_data_wheat_custom for demo purpose) |
crop |
Either "wheat" or "rice". (default: wheat) |
A data frame containing traits, SNP, gene_id, gene_size, and gene_type.
load(system.file("extdata", "precomputed_sample_results_custom.rda", package = "geneNR")) message(sample_results) result <- geneSNPcustom("sample_data_wheat_custom", crop = "wheat")load(system.file("extdata", "precomputed_sample_results_custom.rda", package = "geneNR")) message(sample_results) result <- geneSNPcustom("sample_data_wheat_custom", crop = "wheat")
Imports Hapmap genotypic data file
import_hmp(file_path, header = TRUE, sep = "\t", stringsAsFactors = FALSE)import_hmp(file_path, header = TRUE, sep = "\t", stringsAsFactors = FALSE)
file_path |
Provide the actual path of Hapmap genotypic data file |
header |
by default it will be True |
sep |
by default it will be tab separated |
stringsAsFactors |
by default it will be False |
Hampmap genotypic data
demo_SNP <- system.file("extdata", "demo_SNP.hmp.txt", package = "geneNR") hapmap_data <- import_hmp(demo_SNP) head(hapmap_data)demo_SNP <- system.file("extdata", "demo_SNP.hmp.txt", package = "geneNR") hapmap_data <- import_hmp(demo_SNP) head(hapmap_data)
Imports VCF (Variant Call Format) data file
import_vcf(file_path)import_vcf(file_path)
file_path |
Provide the actual path of the VCF file |
A vcfR object containing the imported data
demo_SNP <- system.file("extdata", "demo_SNP.vcf", package = "geneNR") vcf_data <- import_vcf(demo_SNP) vcf_datademo_SNP <- system.file("extdata", "demo_SNP.vcf", package = "geneNR") vcf_data <- import_vcf(demo_SNP) vcf_data
Plots SNP positions across chromosomes with centromere markers using given chromosome details and SNP data.
plot_SNP( chromosome_details, data, chromosome_color = "steelblue", title = "Chromosome map with SNPs", label_color = "black", image_width = 10, image_height = 10 )plot_SNP( chromosome_details, data, chromosome_color = "steelblue", title = "Chromosome map with SNPs", label_color = "black", image_width = 10, image_height = 10 )
chromosome_details |
A data frame containing chromosome details with columns |
data |
A data frame containing SNP data with columns |
chromosome_color |
Color of the chromosome bars (default: "skyblue"). |
title |
Title of the chromosome plot depicting the identified SNPs |
label_color |
Color of the SNP labels (default: "black"). |
image_width |
width of the chromosome plot |
image_height |
height of the chromosome plot |
A ggplot object for the SNP distribution plot.
chromosome_details <- read.csv(system.file("extdata", "chromosome_details.csv", package = "geneNR")) data <- read.csv(system.file("extdata", "identified_SNP.csv", package = "geneNR")) chromosome_plot <- plot_SNP(chromosome_details = chromosome_details, data = data, chromosome_color = "steelblue" ,title = "Chromosome map with SNPs", label_color = "black", image_width = 15, image_height = 10) print(chromosome_plot)chromosome_details <- read.csv(system.file("extdata", "chromosome_details.csv", package = "geneNR")) data <- read.csv(system.file("extdata", "identified_SNP.csv", package = "geneNR")) chromosome_plot <- plot_SNP(chromosome_details = chromosome_details, data = data, chromosome_color = "steelblue" ,title = "Chromosome map with SNPs", label_color = "black", image_width = 15, image_height = 10) print(chromosome_plot)
Creates a bar chart representing the distribution of SNPs across chromosomes. Allows customization of bar color, label size, and label color. Saves the plot to a user-specified directory or a temporary directory.
plot_summariseSNP( snp_distribution, file_name = "snp_bar_chart.jpeg", output_dir = tempdir(), bar_color = "lightblue", label_size = 3, label_color = "black" )plot_summariseSNP( snp_distribution, file_name = "snp_bar_chart.jpeg", output_dir = tempdir(), bar_color = "lightblue", label_size = 3, label_color = "black" )
snp_distribution |
A data frame with columns |
file_name |
The name of the file to save the plot (default: "snp_bar_chart.jpeg"). |
output_dir |
The directory to save the file (default: |
bar_color |
The color of the bars (default: "lightblue"). |
label_size |
The size of the text labels on the bars (default: 3). |
label_color |
The color of the text labels on the bars (default: "black"). |
A ggplot object for the created bar chart.
demo_SNP <- system.file("extdata", "demo_SNP.hmp.txt", package = "geneNR") data <- import_hmp(demo_SNP) snp_distribution <- summariseSNP(data) plot <- plot_summariseSNP(snp_distribution, bar_color = "skyblue", label_size = 3, label_color = "red") print(plot)demo_SNP <- system.file("extdata", "demo_SNP.hmp.txt", package = "geneNR") data <- import_hmp(demo_SNP) snp_distribution <- summariseSNP(data) plot <- plot_summariseSNP(snp_distribution, bar_color = "skyblue", label_size = 3, label_color = "red") print(plot)
A dataset containing sample data related to genetic markers and associated traits.
sample_data_ricesample_data_rice
A data frame with columns:
SNP identifier, character.
Chromosome location, character.
Position on the chromosome, numeric.
Associated traits, character.
Basha FTM, Sar P, Bhowmick PK, Mahato A, Bisht DS, Iquebal MA, Chakraborty K, Banerjee A, Verma BC, Bhaduri D, Kumar J, Ngangkham U, Saha S, Priyamedha, Mandal NP, Roy S. Genome-wide association study identified QTLs and genes underlying early seedling vigour in aus rice (Oryza sativa L.). Mol Genet Genomics. 2024 Dec 3;299(1):112. doi: 10.1007/s00438-024-02204-8. PMID: 39625651.
data(sample_data_rice) #lazy loadingdata(sample_data_rice) #lazy loading
A dataset containing sample data related to genetic markers and associated traits.
sample_data_rice_qtlsample_data_rice_qtl
A data frame with columns:
Associated traits, character.
Chromosome location, character.
Position on the chromosome where QTL starts, numeric.
Position on the chromosome where QTL stops, numeric.
Generated for demonstration purposes
data(sample_data_rice_qtl) #lazy loadingdata(sample_data_rice_qtl) #lazy loading
A dataset containing sample data related to genetic markers and associated traits.
sample_data_wheatsample_data_wheat
A data frame with columns:
SNP identifier, character.
Chromosome location, character.
Position on the chromosome, numeric.
Associated traits, character.
Generated for demonstration purposes
data(sample_data_wheat) #lazy loadingdata(sample_data_wheat) #lazy loading
A dataset containing sample data related to genetic markers and associated traits.
sample_data_wheat_customsample_data_wheat_custom
A data frame with columns:
Associated traits, character.
SNP identifier, character.
Chromosome location, character.
Position on the chromosome where search window starts, numeric.
Position on the chromosome where search window stops, numeric.
Generated for demonstration purposes
data(sample_data_wheat_custom) #lazy loadingdata(sample_data_wheat_custom) #lazy loading
A dataset containing sample data related to genetic markers and associated traits.
sample_data_wheat_qtlsample_data_wheat_qtl
A data frame with columns:
Associated traits, character.
Chromosome location, character.
Position on the chromosome where QTL starts, numeric.
Position on the chromosome where QTL stops, numeric.
Generated for demonstration purposes
data(sample_data_wheat_qtl) #lazy loadingdata(sample_data_wheat_qtl) #lazy loading
Distribution of SNPs Across Chromosomes
summariseSNP(data)summariseSNP(data)
data |
A data frame containing a column named |
A data frame with chromosome names and the count of SNPs for each chromosome
demo_SNP <- system.file("extdata", "demo_SNP.hmp.txt", package = "geneNR") data <- import_hmp(demo_SNP) snp_distribution <- summariseSNP(data) print(snp_distribution)demo_SNP <- system.file("extdata", "demo_SNP.hmp.txt", package = "geneNR") data <- import_hmp(demo_SNP) snp_distribution <- summariseSNP(data) print(snp_distribution)
Distribution of SNPs Across Chromosomes from VCF
summariseSNP_vcf(vcf_data)summariseSNP_vcf(vcf_data)
vcf_data |
A |
A data frame with chromosome names and the count of SNPs for each chromosome.
demo_SNP <- system.file("extdata", "demo_SNP.vcf", package = "geneNR") vcf_data <- import_vcf(demo_SNP) snp_distribution <- summariseSNP_vcf(vcf_data) print(snp_distribution)demo_SNP <- system.file("extdata", "demo_SNP.vcf", package = "geneNR") vcf_data <- import_vcf(demo_SNP) snp_distribution <- summariseSNP_vcf(vcf_data) print(snp_distribution)